pygeodesy.geodesicw.Geodesic

Package pygeodesy :: Module geodesicw :: Class Geodesic |
[frames] | no frames]

# Class Geodesic

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
            karney._kWrapped --+
                               |
                       _gWrapped --+
                                   |
                                  Geodesic

Wrapper around Karney's class geographiclib.geodesic.Geodesic.

Instance Methods
Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(unused, a_ellipsoid=Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=298.257223`...`, f=None, **name) Return a wrapped `geodesic.Geodesic` instance from Karney's Python geographiclib, provide the latter is installed, otherwise an `ImportError`. |

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
Inherited from `_gWrapped`: `Geodesic`, `GeodesicLine`, `Geodesic_WGS84` Inherited from `karney._kWrapped`: `Math`, `Math_K_2`, `geographiclib` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (unused, a_ellipsoid=Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=298.257223`...`, f=None, **name) Static Method |
Return a wrapped `geodesic.Geodesic` instance from Karney's Python geographiclib, provide the latter is installed, otherwise an `ImportError`. Arguments: `a_ellipsoid` - An ellipsoid (Ellipsoid) or datum (Datum) or the equatorial radius a of the ellipsoid (`meter`). `f` - The flattening of the ellipsoid (`scalar`), required if `a_ellipsoid`) is `meter`, ignored otherwise. `name` - Optional `name=NN` (`str`). Returns: a new object with type S, a subtype of T Overrides: object.__new__